=======
History
=======

0.5.* (2020-12)
------------------

* Support SingletonMetaClass
* Remove unpack feature in `BaseConfig` by removing Mapping Class
* Support nested config for large modular purpose
* Support local object
* Support generic pool object

0.4.* (2020-06)
------------------

* Refatory configure function
* Support property configuration

0.3.* (2020-03)
------------------

* Add proxy and lazy module.
* Add find_caller to trace source of config value
* Refactory ConfigMeta data structure

0.2.* (2019-08)
------------------

* Change global variable to weak reference
* Remove Lock (Prepare to implement optimistic raw lock if necessary)
* Improve Priority Data Structure
* Improve Field Validation
* Use OOP to define call function
* Properer validation and typecast
* Improve Type Annotations
* Import JSON type

0.1.0 (2019-08-01)
------------------

* Init Project.
